# Python notebooks 📒

This folder contains a range of executable Python notebooks, so you can test everything out for yourself. Use these examples as a blueprint for testing on your own data.

Run notebooks locally using [Jupyter](https://jupyter.org/install), or use the links provided in each notebook to run them in Google [Colab](https://colab.research.google.com).
Colab provides an easy-to-use Python virtual environment in the browser.

Notebooks are organized into the following folders:

- [`search`](./search/): Notebooks that demonstrate the fundamentals of Elasticsearch, like indexing embeddings, running lexical, semantic and _hybrid_ searches, and more.

- [`doc-ingestion-and-chunking`](./ingestion-and-chunking/): Notebooks that demonstrate how to ingest and chunk documents for indexing in Elasticsearch from PDF, HTML and JSON with ELSER.

- [`generative-ai`](./generative-ai/): Notebooks that demonstrate various use cases for Elasticsearch as the retrieval engine and vector store for LLM-powered applications.

- [`langchain`](./langchain/): Notebooks that demonstrate how to integrate Elastic with [LangChain](https://langchain-langchain.vercel.app/docs/get_started/introduction.html), a framework for developing applications powered by language models.

- [`integrations`](./integrations/): Notebooks that demonstrate how to integrate popular services and projects with Elasticsearch:

  - [OpenAI](./integrations/openai)
  - [Hugging Face](./integrations/hugging-face)
  - [LlamaIndex](./integrations/llama-index)

- [`enterprise-search`](./enterprise-search/): Notebooks that demonstrate use cases for working with and exporting from Elastic Enterprise Search, App Search, or Workplace Search.
